=== modified file 'diff.py'
--- diff.py	2012-01-23 21:47:33 +0000
+++ diff.py	2012-02-03 21:15:32 +0000
@@ -435,6 +435,8 @@
     differences between two revisions on a branch.
     """
 
+    SHOW_WIDGETS = True
+
     def __init__(self, parent=None, operations=None):
         super(DiffWindow, self).__init__(parent=parent)
         self.set_border_width(0)
@@ -452,10 +454,12 @@
         """Construct the window contents."""
         self.vbox = Gtk.VBox()
         self.add(self.vbox)
-        self.vbox.show()
+        if self.SHOW_WIDGETS:
+            self.vbox.show()
         self.diff = DiffWidget()
         self.vbox.pack_end(self.diff, True, True, 0)
-        self.diff.show_all()
+        if self.SHOW_WIDGETS:
+            self.diff.show_all()
         # Build after DiffWidget to connect signals
         menubar = self._get_menu_bar()
         self.vbox.pack_start(menubar, False, False, 0)
@@ -471,13 +475,17 @@
         mb_view_wrapsource = Gtk.CheckMenuItem.new_with_mnemonic(
             _i18n("Wrap _Long Lines"))
         mb_view_wrapsource.connect('activate', self.diff._on_wraplines_toggled)
-        mb_view_wrapsource.show()
+        if self.SHOW_WIDGETS:
+            mb_view_wrapsource.show()
         mb_view_menu.append(mb_view_wrapsource)
-        mb_view.show()
+        if self.SHOW_WIDGETS:
+            mb_view.show()
         mb_view.set_submenu(mb_view_menu)
-        mb_view.show()
+        if self.SHOW_WIDGETS:
+            mb_view.show()
         menubar.append(mb_view)
-        menubar.show()
+        if self.SHOW_WIDGETS:
+            menubar.show()
         return menubar
 
     def _get_button_bar(self, operations):
@@ -491,11 +499,13 @@
         hbox.set_layout(Gtk.ButtonBoxStyle.START)
         for title, method in operations:
             merge_button = Gtk.Button(title)
-            merge_button.show()
+            if self.SHOW_WIDGETS:
+                merge_button.show()
             merge_button.set_relief(Gtk.ReliefStyle.NONE)
             merge_button.connect("clicked", method)
-            hbox.pack_start(merge_button, expand=False, fill=True)
-        hbox.show()
+            hbox.pack_start(merge_button, False, True, 0)
+        if self.SHOW_WIDGETS:
+            hbox.show()
         return hbox
 
     def _get_merge_target(self):

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2012-01-23 18:10:44 +0000
+++ tests/test_diff.py	2012-02-03 21:15:32 +0000
@@ -35,6 +35,7 @@
     DiffController,
     DiffView,
     DiffWidget,
+    DiffWindow,
     iter_changes_to_status,
     MergeDirectiveController,
     )
@@ -131,6 +132,29 @@
         self.assertFalse(widget.diff_view.show_diff.called)
 
 
+class FakeDiffWindow(DiffWindow):
+
+    SHOW_WIDGETS = False
+
+
+class DiffWindowTestCase(tests.TestCaseWithTransport):
+
+    def test_get_button_bar_with_none(self):
+        window = DiffWindow()
+        self.assertIs(None, window._get_button_bar(None))
+
+    def test_get_button_bar_with_operations(self):
+        window = DiffWindow()
+        method = MockMethod()
+        button_bar = window._get_button_bar([('title', method)])
+        self.assertIsNot(None, button_bar)
+        buttons = button_bar.get_children()
+        self.assertEqual(1, len(buttons))
+        self.assertEqual('title', buttons[0].props.label)
+        buttons[0].emit('clicked')
+        self.assertIs(True, method.called)
+
+
 class MockDiffWidget(object):
 
     def set_diff_text_sections(self, sections):

